%% About File
%--------------------------------------------------------------------------
% filename     : figure1_10yr.m
% author       : Paul Chinwang Yoo
% date created : 12/14/2016
% cd /mq/home/m1pcy00/RA_Work/Taisuke_Nakata/FiscalMultiplier/Fiscal_Multipliers_PostFED/NL_2SMS_TShock
% figure1_10yr.m
%--------------------------------------------------------------------------

%% Main Code
clear all
close all
clc

quarters   = [1 4 40];

file_names    = {'irf_G_MODEL_'};
shock_files   = {'delshock_NITR_corr_FM_NL','gshock_NITR_corr_FM_NL','delshock_gshock_NITR_corr_FM_NL'};
horz_types    = {'','_1yr','_10yr'};
file_type     = {'.dat'};
line_styles   = {'k','k--','k-.'};
line_styles_2 = {'r','r--','r-.'};

% Create the IRF non-expect matrix
for i = 1:length(shock_files),
    for j = 1:length(horz_types),
        disp(char(strcat(file_names(1),shock_files(i),horz_types(j),file_type(1))));
        mat = dlmread(char(strcat(file_names(1),shock_files(i),horz_types(j),file_type(1))));
%         mat = mat(1:100,:);
        IRF_ne(:,:,i,j) = mat;
    end
end

cBET     = 0.9925d0;
cCHIc    = 1d0;
cCHIn    = 0.2d0;
cTHETA   = 5d0;
cPHI     = 160d0;
cPHIpi   = 3d0;
cPHIy    = 1d0;
cGAM     = 0.2d0;
pLR      = 0.825;

cPIBAR = 1d0;
cRBAR  = cPIBAR / cBET;
cCBAR  = ( ( cTHETA - 1d0 )*( 1d0 - cGAM )^( cCHIn ) / cTHETA )^(1d0/(cCHIn+cCHIc));
cYBAR  = cCBAR/(1d0-cGAM);
cGBAR  = cGAM*cCBAR/(1d0-cGAM);
cWBAR  = cYBAR^(cCHIn)*cCBAR^(cCHIc);

for i = 1:40
    if i == 1
        e_y_ss(i) = cYBAR;
        e_g_ss(i) = cGBAR;
    else
        e_y_ss(i) = cBET*e_y_ss(i-1);
        e_g_ss(i) = cBET*e_g_ss(i-1);
    end
end

rhoR_col = 1;
y_col_ne = 2;
g_col_ne = 3;
r_col_ne = 4;

% Find the rhoR's that will wield ZLB both with g_shock
check_mat = IRF_ne(:,r_col_ne,3,1);
rhoR_vals = IRF_ne(:,rhoR_col,3,1);
ZLB_check = find(check_mat(:)==1);

n_rhoR = length(rhoR_vals);

periods = 1;
% FMs for the correlated and indendent shocks cases
for i = 1:length(rhoR_vals)
    for j = 1:length(horz_types)
        fm_corr_ZLB(i,j)  = (IRF_ne(periods*(i-1)+1,y_col_ne,3,j)-IRF_ne(periods*(i-1)+1,y_col_ne,1,j))/(IRF_ne(periods*(i-1)+1,g_col_ne,3,j)-IRF_ne(periods*(i-1)+1,g_col_ne,1,j));
    end
end
for i = 1:length(rhoR_vals)
    for j = 1:length(horz_types)
        fm_corr_NZLB(i,j) = (IRF_ne(periods*(i-1)+1,y_col_ne,2,j) - sum(e_y_ss(1:quarters(j))))/(IRF_ne(periods*(i-1)+1,g_col_ne,2,j) - sum(e_g_ss(1:quarters(j))));
    end
end
    
fig1 = figure(1);
grid on
box on
hold on
% for j = 1:length(horz_types)
%     p(1,j) = plot(rhoR_vals,fm_corr_ZLB(:,j),line_styles{j},'LineWidth',3);
%     p(2,j) = plot(rhoR_vals,fm_corr_NZLB(:,j),line_styles_2{j},'LineWidth',3);
% end
p(1,1) = plot(rhoR_vals,fm_corr_ZLB(:,3),line_styles{1},'LineWidth',3);
% p(2,1) = plot(rhoR_vals,fm_corr_NZLB(:,3),line_styles_2{1},'LineWidth',3);
p(2,1) = plot(rhoR_vals,fm_corr_NZLB(:,3),line_styles_2{2},'LineWidth',3);
leg  = legend([p(1,1) p(2,1)],'ZLB episode','No ZLB episode');
set(leg,'Location','NorthWest','interpreter','latex','FontSize',30)
t(1) = text(0.69,1.75,{'ZLB Binds','at $t=1$'});
t(2) = text(0.928,1.8,{'ZLB Does','Not Bind','at $t=1$'});
annotation('arrow',[.843 .793],[.76 .76])
annotation('arrow',[.85 .9],[.76 .76])
set([t(1) t(2)],'interpreter','latex','FontSize',26)
set(gca,'XLim',[0 1],'XTick',(0:0.2:1),'YLim',[0 2],'YTick',(0:0.5:2),'FontSize',20);
plot([rhoR_vals(ZLB_check(length(ZLB_check))+1),rhoR_vals(ZLB_check(length(ZLB_check))+1)],get(gca,'YLim'),'k--','LineWidth',1)
xlabel('$\rho_{r}$','interpreter','latex','FontSize',30)
ylabel('Fiscal Multiplier','interpreter','latex','FontSize',30)
set(fig1,'PaperOrientation','Landscape');
set(fig1,'PaperPosition',[0 0 11 8.5]);
% print(fig1,'-depsc','FMs_NL_2SMS_ZShock_10yr.eps');
% print(fig1,'-dpdf','FMs_NL_2SMS_ZShock_10yr.pdf');
print(fig1,'-depsc','FMs_NL_2SMS_ZShock_10yr_colorless.eps');
print(fig1,'-dpdf','FMs_NL_2SMS_ZShock_10yr_colorless.pdf');