%% About File
%--------------------------------------------------------------------------
% filename     : figure2.m
% author       : Paul Chinwang Yoo
% date created : 12/14/2016
% cd /mq/home/m1pcy00/RA_Work/Taisuke_Nakata/FiscalMultiplier/Fiscal_Multipliers_PostFED/NL_2SMS_TShock
% figure2.m
%--------------------------------------------------------------------------

%% Main Code
clear all
close all
clc

addpath('G:\RA_Work\Taisuke_Nakata\ZeroLowerBound\FiscalMultiplier\prog_Paul\AltInertialRule');
addpath('G:\RA_Work\Taisuke_Nakata\ZeroLowerBound\FiscalMultiplier\prog_Paul\PLT');
addpath('G:\RA_Work\Taisuke_Nakata\ZeroLowerBound\FiscalMultiplier\prog_Paul\RWRule');

file_names   = {'irf_G_MODEL_'};
shock_files  = {'delshock_NITR_corr_FM_NL','delshock_gshock_NITR_corr_FM_NL'};
alt_files    = {'_AIR','_PLT','_RWR'};
irf_types    = {'_IRF8Q'};
expect_files = {'e_'};
file_type    = {'.dat'};

cBET     = 0.9925d0;
cCHIc    = 1d0;
cCHIn    = 0.2d0;
cTHETA   = 5d0;
cPHI     = 160d0;
cPHIpi   = 3d0;
cPHIy    = 1d0;
cGAM     = 0.2d0;
pLR      = 0.825;

cPIBAR = 1d0;
cRBAR  = cPIBAR / cBET;
cCBAR  = ( ( cTHETA - 1d0 )*( 1d0 - cGAM )^( cCHIn ) / cTHETA )^(1d0/(cCHIn+cCHIc));
cYBAR  = cCBAR/(1d0-cGAM);
cGBAR  = cGAM*cCBAR/(1d0-cGAM);
cWBAR  = cYBAR^(cCHIn)*cCBAR^(cCHIc);

ylims1  = [-35 7.5;-40 7.5;-11 1.5;0 1.5];
ylims2  = [-.75 5;-1.45 0;-.15 .75;1 2.5];
ylimse1 = [0 1.25;-11 0;1 10];
ylimse2 = [1 2.5;0 0.725;0.8 1.625];

% Create the IRF non-expect matrix
for i = 1:length(shock_files)
    for j = 1:length(alt_files)
        for k = 1:length(irf_types)
            disp(char(strcat(file_names(1),shock_files(i),alt_files(j),irf_types(k),file_type(1))));
            mat = dlmread(char(strcat(file_names(1),shock_files(i),alt_files(j),irf_types(k),file_type(1))));
            IRF_ne(:,:,i,j,k) = mat;
        end
    end
end

period_col = 1;
cLz_col    = 2;
del_col_ne = 3;
g_col_ne   = 4;
y_col_ne   = 5;
c_col_ne   = 6;
pi_col_ne  = 7;
r_col_ne   = 8;

vars = {'$Y_{t}$','$C_{t}$','$\Pi_{t}$','$R_{t}$'}; 
cols = [y_col_ne c_col_ne pi_col_ne r_col_ne]; 
time = (1:1:40)';

fig1 = figure(1);
for i = 1:length(alt_files)
    for j = 1:length(vars)
        subplot(length(vars)+1,length(alt_files)+1,(j-1)*(length(alt_files)+1) + i)
        grid on
        box on
        hold on
        plot(time,IRF_ne(:,cols(j),1,i,1),'k',time,IRF_ne(:,cols(j),2,i,1),'r','LineWidth',2)
        if i == 1
            ylabel(vars(j),'interpreter','latex','FontSize',15)
        end
        if j == 1
            if i == 1
%                 title(strcat('$AIR \hspace{.2em} (\rho_{r} = 0.85)$'),'interpreter','latex','FontSize',15)
                title(strcat('$AIR$'),'interpreter','latex','FontSize',15)
                ll = legend('w/o G','w/ G','interpreter','latex');
                set(ll,'Location','SouthEast','FontSize',10)
            elseif i == 2
%                 title(strcat('$PLT \hspace{.2em} (\phi_{p} = 1)$'),'interpreter','latex','FontSize',15)
                title(strcat('$PLT$'),'interpreter','latex','FontSize',15)
            else
%                 title(strcat('$RW \hspace{.2em} (2000) \hspace{.2em} Rule \hspace{.2em} (\alpha_{z} = 1)$'),'interpreter','latex','FontSize',15)
                title(strcat('$RW \hspace{.2em} (2000) \hspace{.2em} Rule$'),'interpreter','latex','FontSize',15)
            end
        end
        set(gca,'XLim',[0 25],'XTick',(0:5:25),'FontSize',12)
        if j == 4
            set(gca,'YLim',[0 4],'YTick',(0:1:4))
            if i == 1                
                annotation('arrow',[0.205 0.215],[0.27 0.23])
                % Make the rectangle for the magnifier : specifying the position and the
                % size of the rectangle
                x_r = 8; y_r = 0; w_r = 4; h_r = 3;
                rectangle('Position',[x_r,y_r,w_r,h_r],'EdgeColor',[0 0 0]);
                % Specifying the position and the size of the mangnified plot
                x_a1 = 0.18; y_a1 = 0.04; w_a1 = 0.1; h_a1 = 0.18;
                ax1 = axes('Units', 'Normalized', ...
                    'Position', [x_a1, y_a1, w_a1, h_a1], ...
                    'Box', 'on', ...
                    'LineWidth', 1, ...
                    'Color', [1, 1, 1]);
                hold on
                grid on
                plot(time,IRF_ne(:,cols(j),1,i,1),'k',time,IRF_ne(:,cols(j),2,i,1),'r','LineWidth',2)
                set(gca,'XLim',[8 12],'XTick',[8 10 12],'YTick',[0 1 2 3],'FontSize',10);
                axis([x_r, x_r+w_r, y_r, y_r+h_r]);
            elseif i == 2
                annotation('arrow',[0.412 0.42],[0.27 0.23])
                % Make the rectangle for the magnifier : specifying the position and the
                % size of the rectangle
                x_r = 12; y_r = 0; w_r = 4; h_r = 2;
                rectangle('Position',[x_r,y_r,w_r,h_r],'EdgeColor',[0 0 0]);
                % Specifying the position and the size of the mangnified plot
                x_a1 = 0.39; y_a1 = 0.04; w_a1 = 0.1; h_a1 = 0.18;
                ax1 = axes('Units', 'Normalized', ...
                    'Position', [x_a1, y_a1, w_a1, h_a1], ...
                    'Box', 'on', ...
                    'LineWidth', 1, ...
                    'Color', [1, 1, 1]);
                hold on
                grid on
                plot(time,IRF_ne(:,cols(j),1,i,1),'k','LineWidth',2)
                plot(time,IRF_ne(:,cols(j),2,i,1),'r','LineWidth',2)
                set(gca,'XLim',[12 18],'XTick',[12 14 16],'YTick',[0 1 2],'FontSize',10);
                axis([x_r, x_r+w_r, y_r, y_r+h_r]);
            else
                annotation('arrow',[0.65 0.658],[0.27 0.23])
                % Make the rectangle for the magnifier : specifying the position and the
                % size of the rectangle
                x_r = 16; y_r = 0; w_r = 4; h_r = 3;
                rectangle('Position',[x_r,y_r,w_r,h_r],'EdgeColor',[0 0 0]);
                % Specifying the position and the size of the mangnified plot
                x_a1 = 0.6; y_a1 = 0.04; w_a1 = 0.1; h_a1 = 0.18;
                ax1 = axes('Units', 'Normalized', ...
                    'Position', [x_a1, y_a1, w_a1, h_a1], ...
                    'Box', 'on', ...
                    'LineWidth', 1, ...
                    'Color', [1, 1, 1]);
                hold on
                grid on
                plot(time,IRF_ne(:,cols(j),1,i,1),'k',time,IRF_ne(:,cols(j),2,i,1),'r','LineWidth',2)
                set(gca,'XLim',[16 20],'XTick',[16 18 20],'YTick',[0 1 2 3],'FontSize',10);
                axis([x_r, x_r+w_r, y_r, y_r+h_r]);                
            end            
        end
        
    end
end
set(fig1,'PaperOrientation','Landscape');
set(fig1,'PaperPosition',[0 0 11 8.5]);
print(fig1,'-depsc','IRF_AltRules_extended.eps');
print(fig1,'-dpdf','IRF_AltRules_extended.pdf');